##  Data Breach Contact
In the Data Breach Contact section, provide the contact person details who should be informed in the event of a data breach..
![Data Breach Contact Information Fields](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749a8427a4410149e07f31997ad84e8_LowRes.png)
Data Breach Contact Information Fields
